{% load i18n %}
<div class="grp-module">
	<div class="grp-row">
	    <label>{% blocktrans with title|capfirst as filter_title %}{{ filter_title }}{% endblocktrans %}</label>
	    <select class="grp-filter-choice">
	        {% for choice in choices %}<option value="{{ choice.query_string|iriencode }}"{% if choice.selected %} selected='selected'{% endif %}>{{ choice.display }}</option>{% endfor %}
	    </select>
	</div>
</div>