/* -----------------------------------------------------------------------

   Please use this file if you want to deploy any custom TinyMCE styles
   which are not covered by the Grappelli skin.

   If you use background-images make sure to put them into the folder
   "img/customized/"

----------------------------------------------------------------------- */



/* 	Page Break
----------------------------------------------------------------------- */

body#tinymce img.mcePageBreak {
   display: block;
   width: 100%;
   height: 16px;
   margin-top: 12px;
   background: #fff url(img/customized/pagebreak.png) 0 0 repeat-x;
}