/* -- Import Basic Documentstructure CSS ---------- */

@import url('content_documentstructure.css');

/* -- Language Specific Settings ---------- */

body#tinymce h1:before          { content: "Nadpis 1"; }
body#tinymce h2:before          { content: "Nadpis 2"; }
body#tinymce h3:before          { content: "Nadpis 3"; }
body#tinymce h4:before          { content: "Nadpis 4"; }
body#tinymce ol:before          { content: "Seřazený seznam"; }
body#tinymce ul:before          { content: "Neseřazený seznam"; }
body#tinymce p:before           { content: "Odstavec"; }
body#tinymce code:before        { content: "Kód programu"; }
body#tinymce pre:before         { content: "Předformátovaný text"; }
body#tinymce blockquote:before  { content: "Citace"; }
body#tinymce div:before         { content: "Div"; }
