{% extends "admin/change_list.html" %}
{% load i18n %}

{% block object-tools-items %}
    {% if user.is_superuser %}
    <li>
        <a href="dump/">{% trans "Dump data" %}</a>
    </li>
    <li>
        <a href="{% url 'load-data'  %}{% if is_popup %}?_popup=1{% endif %}">
            {% trans "Load data" %}
        </a>
    </li>
    {% endif %}
    <li><a href="add/{% if is_popup %}?_popup=1{% endif %}" class="grp-add-link grp-state-focus">{% blocktrans with cl.opts.verbose_name as name %}Add {{ name }}{% endblocktrans %}</a></li>
{% endblock %}
